@@ -10,7 +10,7 @@ use File::Basename              qw[dirname];
 
 use Cwd                         qw[cwd];
 use Carp                        qw[carp];
-use IPC::Cmd                    qw[can_run run];
+use IPC::Cmd                    qw[can_run run QUOTE];
 use File::Path                  qw[mkpath];
 use Params::Check               qw[check];
 use Module::Load::Conditional   qw[can_load];
@@ -21,14 +21,11 @@ use vars    qw[ $VERBOSE $PREFER_BIN $FROM_EMAIL $USER_AGENT
                 $FTP_PASSIVE $TIMEOUT $DEBUG $WARN
             ];
 
-use constant QUOTE  => do { $^O eq 'MSWin32' ? q["] : q['] };            
-            
-
-$VERSION        = '0.16';
+$VERSION        = '0.18';
 $VERSION        = eval $VERSION;    # avoid warnings with development releases
 $PREFER_BIN     = 0;                # XXX TODO implement
 $FROM_EMAIL     = 'File-Fetch@example.com';
-$USER_AGENT     = 'File::Fetch/$VERSION';
+$USER_AGENT     = "File::Fetch/$VERSION";
 $BLACKLIST      = [qw|ftp|];
 $METHOD_FAIL    = { };
 $FTP_PASSIVE    = 1;
@@ -51,11 +48,13 @@ local $Module::Load::Conditional::VERBOSE   = 0;
 local $Module::Load::Conditional::VERBOSE   = 0;
 
 ### see what OS we are on, important for file:// uris ###
-use constant ON_WIN         => ($^O eq 'MSWin32');
-use constant ON_VMS         => ($^O eq 'VMS');                                
-use constant ON_UNIX        => (!ON_WIN);
-use constant HAS_VOL        => (ON_WIN);
-use constant HAS_SHARE      => (ON_WIN);
+use constant ON_WIN     => ($^O eq 'MSWin32');
+use constant ON_VMS     => ($^O eq 'VMS');                                
+use constant ON_UNIX    => (!ON_WIN);
+use constant HAS_VOL    => (ON_WIN);
+use constant HAS_SHARE  => (ON_WIN);
+
+
 =pod
 
 =head1 NAME
@@ -147,7 +146,7 @@ result of $ff->output_file will be used.
 ##########################
 
 {
-    ### template for new() and autogenerated accessors ###
+    ### template for autogenerated accessors ###
     my $Tmpl = {
         scheme          => { default => 'http' },
         host            => { default => 'localhost' },
